Trait lender::IteratorExt

source ·
pub trait IteratorExt<I: Iterator + Sized> {
    // Required method
    fn into_lender(self) -> FromIter<I>;
}
Extension trait adding to Iterator the method into_lender, which turns an Iterator into a Lender without allocation.

Required Methods

source

fn into_lender(self) -> FromIter<I>

Turn this Iterator into a Lender without allocation.

This method is a convenient entry point for from_iter.

Implementors

source

impl<I: Iterator> IteratorExt<I> for I